@@ -13,41 +13,21 @@
 infection.icm <- function(dat, at) {
 
   ## Expected acts
-  if (dat$param$groups == 1) {
     acts <- round(dat$param$act.rate * dat$epi$num[at - 1] / 2)
-  }
-  if (dat$param$groups == 2) {
-    if (dat$param$balance == "g1") {
-      acts <- round(dat$param$act.rate *
-                      (dat$epi$num[at - 1] + dat$epi$num.g2[at - 1]) / 2)
-    }
-    if (dat$param$balance == "g2") {
-      acts <- round(dat$param$act.rate.g2 *
-                      (dat$epi$num[at - 1] + dat$epi$num.g2[at - 1]) / 2)
-    }
-  }
-
 
   ## Edgelist
-  if (dat$param$groups == 1) {
-    p1 <- ssample(which(dat$attr$active == 1), acts, replace = TRUE)
-    p2 <- ssample(which(dat$attr$active == 1), acts, replace = TRUE)
-  } else {
-    p1 <- ssample(which(dat$attr$active == 1 & dat$attr$group == 1),
-                  acts, replace = TRUE)
-    p2 <- ssample(which(dat$attr$active == 1 & dat$attr$group == 2),
-                  acts, replace = TRUE)
-  }
+  p1 <- ssample(which(dat$attr$active == 1), acts, replace = TRUE)
+  p2 <- ssample(which(dat$attr$active == 1), acts, replace = TRUE)
+
 
   del <- NULL
   if (length(p1) > 0 & length(p2) > 0) {
     del <- data.frame(p1, p2)
-    if (dat$param$groups == 1) {
       while (any(del$p1 == del$p2)) {
         del$p2 <- ifelse(del$p1 == del$p2,
                          ssample(which(dat$attr$active == 1), 1), del$p2)
       }
-    }
+
 
 
     ## Discordant edgelist
@@ -60,39 +40,27 @@ infection.icm <- function(dat, at) {
 
     ## Transmission on edgelist
     if (nrow(del) > 0) {
-      if (dat$param$groups == 1) {
-        del$tprob <- dat$param$inf.prob
-      } else {
-        del$tprob <- ifelse(del$p1.stat == "s", dat$param$inf.prob,
-                                                dat$param$inf.prob.g2)
-      }
+      del$tprob <- dat$param$inf.prob
+
       if (!is.null(dat$param$inter.eff) && at >= dat$param$inter.start) {
         del$tprob <- del$tprob * (1 - dat$param$inter.eff)
       }
       del$trans <- rbinom(nrow(del), 1, del$tprob)
       del <- del[del$trans == TRUE, ]
       if (nrow(del) > 0) {
-        if (dat$param$groups == 1) {
           newIds <- unique(ifelse(del$p1.stat == "s", del$p1, del$p2))
           nInf <- length(newIds)
-        }
-        if (dat$param$groups == 2) {
-          newIdsg1 <- unique(del$p1[del$p1.stat == "s"])
-          newIdsg2 <- unique(del$p2[del$p2.stat == "s"])
-          nInf <- length(newIdsg1)
-          nInfg2 <- length(newIdsg2)
-          newIds <- c(newIdsg1, newIdsg2)
-        }
+
         dat$attr$status[newIds] <- "i"
         dat$attr$infTime[newIds] <- at
       } else {
-        nInf <- nInfg2 <- 0
+        nInf <- 0
       }
     } else {
       nInf <- nInfg2 <- 0
     }
   } else {
-    nInf <- nInfg2 <- 0
+    nInf <- 0
   }
 
 
@@ -102,13 +70,6 @@ infection.icm <- function(dat, at) {
   } else {
     dat$epi$si.flow[at] <- nInf
   }
-  if (dat$param$groups == 2) {
-    if (at == 2) {
-      dat$epi$si.flow.g2 <- c(0, nInfg2)
-    } else {
-      dat$epi$si.flow.g2[at] <- nInfg2
-    }
-  }
 
   return(dat)
 
@@ -140,13 +101,155 @@ recovery.icm <- function(dat, at) {
   active <- dat$attr$active
   status <- dat$attr$status
 
-  groups <- dat$param$groups
+  type <- dat$control$type
+  recovState <- ifelse(type == "SIR", "r", "s")
+
+  rec.rate <- dat$param$rec.rate
+
+  nRecov <- 0
+  idsElig <- which(active == 1 & status == "i")
+  nElig <- length(idsElig)
+
+  if (nElig > 0) {
+    #ratesElig <- rec.rate[idsElig]
+      vecRecov <- which(rbinom(nElig, 1, rec.rate) == 1)
+      if (length(vecRecov) > 0) {
+        idsRecov <- idsElig[vecRecov]
+        nRecov <- length(idsRecov)
+        status[idsRecov] <- recovState
+      }
+  }
+  dat$attr$status <- status
+
+
+  # Output ------------------------------------------------------------------
+  outName <- ifelse(type == "SIR", "ir.flow", "is.flow")
+
+  ## Summary statistics
+  if (at == 2) {
+    dat$epi[[outName[1]]] <- c(0, nRecov)
+  } else {
+    dat$epi[[outName[1]]][at] <- nRecov
+  }
+
+  return(dat)
+}
+
+
+#' @title Primary Infection Module for icm
+#'
+#' @description This function simulates the main infection process given the
+#'              current state of the actors in the system.
+#'
+#' @param dat Master data list object.
+#' @param at Current time step.
+#'
+#' @export
+#' @keywords internal
+#'
+infection.icm.bip <- function(dat, at) {
+
+  ## Expected acts
+    if (dat$param$balance == "g1") {
+      acts <- round(dat$param$act.rate *
+                      (dat$epi$num[at - 1] + dat$epi$num.g2[at - 1]) / 2)
+    }
+    if (dat$param$balance == "g2") {
+      acts <- round(dat$param$act.rate.g2 *
+                      (dat$epi$num[at - 1] + dat$epi$num.g2[at - 1]) / 2)
+    }
+
+
+  ## Edgelist
+    p1 <- ssample(which(dat$attr$active == 1 & dat$attr$group == 1),
+                  acts, replace = TRUE)
+    p2 <- ssample(which(dat$attr$active == 1 & dat$attr$group == 2),
+                  acts, replace = TRUE)
+
+  del <- NULL
+  if (length(p1) > 0 & length(p2) > 0) {
+    del <- data.frame(p1, p2)
+
+    ## Discordant edgelist
+    del$p1.stat <- dat$attr$status[del$p1]
+    del$p2.stat <- dat$attr$status[del$p2]
+    serodis <- (del$p1.stat == "s" & del$p2.stat == "i") |
+      (del$p1.stat == "i" & del$p2.stat == "s")
+    del <- del[serodis == TRUE, ]
+
+
+    ## Transmission on edgelist
+    if (nrow(del) > 0) {
+        del$tprob <- ifelse(del$p1.stat == "s", dat$param$inf.prob,
+                            dat$param$inf.prob.g2)
+      if (!is.null(dat$param$inter.eff) && at >= dat$param$inter.start) {
+        del$tprob <- del$tprob * (1 - dat$param$inter.eff)
+      }
+      del$trans <- rbinom(nrow(del), 1, del$tprob)
+      del <- del[del$trans == TRUE, ]
+      if (nrow(del) > 0) {
+          newIdsg1 <- unique(del$p1[del$p1.stat == "s"])
+          newIdsg2 <- unique(del$p2[del$p2.stat == "s"])
+          nInf <- length(newIdsg1)
+          nInfg2 <- length(newIdsg2)
+          newIds <- c(newIdsg1, newIdsg2)
+          dat$attr$status[newIds] <- "i"
+          dat$attr$infTime[newIds] <- at
+      } else {
+        nInf <- nInfg2 <- 0
+      }
+    } else {
+      nInf <- nInfg2 <- 0
+    }
+  } else {
+    nInf <- nInfg2 <- 0
+  }
+
+
+  ## Output
+  if (at == 2) {
+    dat$epi$si.flow <- c(0, nInf)
+    dat$epi$si.flow.g2 <- c(0, nInfg2)
+  } else {
+    dat$epi$si.flow[at] <- nInf
+    dat$epi$si.flow.g2[at] <- nInfg2
+  }
+
+  return(dat)
+
+}
+
+
+#' @title Recovery: icm Module
+#'
+#' @description This function simulates recovery from the infected state
+#'              either to an distinct recovered state (SIR model type) or back
+#'              to a susceptible state (SIS model type), for use in
+#'              \code{\link{icm}}.
+#'
+#' @param dat Master data list object.
+#' @param at Current time step.
+#'
+#' @export
+#' @keywords internal
+#'
+recovery.icm.bip <- function(dat, at) {
+
+  # Conditions --------------------------------------------------------------
+  if (!(dat$control$type %in% c("SIR", "SIS"))) {
+    return(dat)
+  }
+
+
+  # Variables ---------------------------------------------------------------
+  active <- dat$attr$active
+  status <- dat$attr$status
+
   group <- dat$attr$group
 
   type <- dat$control$type
   recovState <- ifelse(type == "SIR", "r", "s")
 
-  rec.rand <- dat$control$rec.rand
   rec.rate <- dat$param$rec.rate
   rec.rate.g2 <- dat$param$rec.rate.g2
 
@@ -160,7 +263,6 @@ recovery.icm <- function(dat, at) {
     rates <- c(rec.rate, rec.rate.g2)
     ratesElig <- rates[gElig]
 
-    if (rec.rand == TRUE) {
       vecRecov <- which(rbinom(nElig, 1, ratesElig) == 1)
       if (length(vecRecov) > 0) {
         idsRecov <- idsElig[vecRecov]
@@ -168,14 +270,6 @@ recovery.icm <- function(dat, at) {
         nRecovG2 <- sum(group[idsRecov] == 2)
         status[idsRecov] <- recovState
       }
-    } else {
-      nRecov <- min(round(sum(ratesElig[gElig == 1])), sum(gElig == 1))
-      status[ssample(idsElig[gElig == 1], nRecov)] <- recovState
-      if (groups == 2) {
-        nRecovG2 <- min(round(sum(ratesElig[gElig == 2])), sum(gElig == 2))
-        status[ssample(idsElig[gElig == 2], nRecov)] <- recovState
-      }
-    }
   }
   dat$attr$status <- status
 
@@ -190,13 +284,12 @@ recovery.icm <- function(dat, at) {
   } else {
     dat$epi[[outName[1]]][at] <- nRecov
   }
-  if (groups == 2) {
     if (at == 2) {
       dat$epi[[outName[2]]] <- c(0, nRecovG2)
     } else {
       dat$epi[[outName[2]]][at] <- nRecovG2
     }
-  }
 
   return(dat)
 }
+
