@@ -114,12 +114,13 @@ verbose.net <- function(x, type, s = 1, at = 2) {
         cat("\n----------------------------")
         cat("\nSimulation: ", s, "/", x$control$nsims, sep = "")
         cat("\nTimestep: ", at, "/", x$control$nsteps, sep = "")
-        status <- x$attr$status
+        active <- x$attr$active
+        status <- x$attr$status[which(active == 1)]
         if (class(status) == "character") {
           status <- ifelse(status == "i", 1, 0)
         }
         cat("\nPrevalence:", sum(status, na.rm = TRUE))
-        cat("\nPopulation Size:", sum(x$attr$active == 1))
+        cat("\nPopulation Size:", sum(active == 1))
         cat("\n----------------------------")
       }
     }
