@@ -5,7 +5,7 @@ context("Network extended models")
 test_that("edges models", {
   skip_on_cran()
 
-  nw <- network.initialize(n = 100, directed = FALSE)
+  nw <- network_initialize(n = 100)
   est <- netest(nw, formation = ~edges, target.stats = 25,
                 coef.diss = dissolution_coefs(~offset(edges), 10, 0),
                 verbose = FALSE)
@@ -37,7 +37,7 @@ test_that("edges models", {
   expect_is(x, "netsim")
   expect_is(as.data.frame(x), "data.frame")
   expect_true(max(x$epi$i.num) == 1)
-  expect_true(max(x$epi$si.flow) == 0)
+  expect_true(max(x$epi$si.flow, na.rm = TRUE) == 0)
   expect_output(summary(x, at = 25), "EpiModel Summary")
   plot(x)
   plot(x, y = "si.flow", mean.smooth = TRUE)
@@ -74,14 +74,13 @@ test_that("edges models", {
   param <- param.net(inf.prob = 1)
   init <- init.net(i.num = 1)
   control <- control.net(type = "SI", nsims = 2, nsteps = 25,
-                         verbose = FALSE, tea.status = TRUE)
+                         verbose = FALSE)
   x <- netsim(est, param, init, control)
   expect_is(x, "netsim")
   expect_is(as.data.frame(x), "data.frame")
   expect_true(max(x$epi$i.num) >= 1)
   expect_true(max(x$epi$i.num) <= 100)
-  expect_true(x$control$tea.status, TRUE)
-  expect_true(sum(get.vertex.attribute.active(x$network[[1]],
+  expect_true(sum(get.vertex.attribute.active(x$network[[1]][[1]],
                                               prefix = "testatus", at = 1) == "i") >= 0)
   expect_output(summary(x, at = 25), "EpiModel Summary")
   plot(x)
@@ -97,7 +96,7 @@ test_that("edges models", {
   init <- init.net(status.vector = c(rep("i", 10),
                                      rep("s", 90)))
   control <- control.net(type = "SI", nsims = 2, nsteps = 25,
-                         verbose = FALSE, tea.status = FALSE)
+                         verbose = FALSE)
   x <- netsim(est, param, init, control)
   expect_is(x, "netsim")
   expect_is(as.data.frame(x), "data.frame")
@@ -108,12 +107,12 @@ test_that("edges models", {
   plot(x)
   plot(x, y = "si.flow", mean.smooth = TRUE)
   plot(x, type = "formation")
-  expect_error(plot(x, type = "network", col.status = TRUE))
+  plot(x, type = "network", col.status = TRUE)
   test_net(x)
   rm(x)
 
   ## "SIR, 1M, CL: 1 sim"
-  param <- param.net(inf.prob = 0.5, rec.rate = 0.02)
+  param <- param.net(inf.prob = 0.5, rec.rate = 0.01)
   init <- init.net(i.num = 10, r.num = 0)
   control <- control.net(type = "SIR", nsims = 1, nsteps = 25,
                          verbose = FALSE)
@@ -132,7 +131,7 @@ test_that("edges models", {
   rm(x)
 
   ## "SIR, 1M, CL: 1 sim, inf.prob=0"
-  param <- param.net(inf.prob = 0, rec.rate = 0.02)
+  param <- param.net(inf.prob = 0, rec.rate = 0.01)
   init <- init.net(i.num = 10, r.num = 0)
   control <- control.net(type = "SIR", nsims = 1,
                          nsteps = 25, verbose = FALSE)
@@ -140,7 +139,7 @@ test_that("edges models", {
   expect_is(x, "netsim")
   expect_is(as.data.frame(x), "data.frame")
   expect_true(max(x$epi$i.num) == 10)
-  expect_true(max(x$epi$si.flow) == 0)
+  expect_true(max(x$epi$si.flow, na.rm = TRUE) == 0)
   expect_output(summary(x, at = 25), "EpiModel Summary")
   plot(x)
   plot(x, y = "si.flow", mean.smooth = TRUE)
@@ -217,7 +216,7 @@ test_that("edges models", {
   expect_is(x, "netsim")
   expect_is(as.data.frame(x), "data.frame")
   expect_true(max(x$epi$i.num) == 1)
-  expect_true(max(x$epi$si.flow) == 0)
+  expect_true(max(x$epi$si.flow, na.rm = TRUE) == 0)
   expect_output(summary(x, at = 25), "EpiModel Summary")
   plot(x)
   plot(x, y = "si.flow", mean.smooth = TRUE)
@@ -248,13 +247,12 @@ test_that("edges models", {
   param <- param.net(inf.prob = 1, rec.rate = 0.01)
   init <- init.net(i.num = 1)
   control <- control.net(type = "SIS", nsims = 2, nsteps = 25,
-                         tea.status = TRUE, verbose = FALSE)
+                         verbose = FALSE)
   x <- netsim(est, param, init, control)
   expect_is(x, "netsim")
   expect_is(as.data.frame(x), "data.frame")
   expect_true(max(x$epi$i.num) <= 100)
-  expect_true(x$control$tea.status, TRUE)
-  expect_true(sum(get.vertex.attribute.active(x$network[[1]],
+  expect_true(sum(get.vertex.attribute.active(x$network[[1]][[1]],
                                               prefix = "testatus", at = 1) == "i") >= 0)
   expect_output(summary(x, at = 25), "EpiModel Summary")
   plot(x)
@@ -269,7 +267,7 @@ test_that("edges models", {
   param <- param.net(inf.prob = 0.5, rec.rate = 0.01)
   init <- init.net(status.vector = c(rep("i", 10), rep("s", 90)))
   control <- control.net(type = "SIS", nsims = 2, nsteps = 25,
-                         verbose = FALSE, tea.status = FALSE)
+                         verbose = FALSE)
   x <- netsim(est, param, init, control)
   expect_is(x, "netsim")
   expect_is(as.data.frame(x), "data.frame")
@@ -281,7 +279,7 @@ test_that("edges models", {
   plot(x, y = "si.flow", mean.smooth = TRUE)
   plot(x, type = "formation")
   plot(x, type = "network")
-  expect_error(plot(x, type = "network", sims = "mean", col.status = TRUE))
+  plot(x, type = "network", sims = "mean", col.status = TRUE)
   test_net(x)
 })
 
@@ -289,19 +287,18 @@ test_that("edges models", {
 ################################################################################
 
 test_that("High departure rate models", {
-
+  skip_on_cran()
   ## "netsim: 1M, ds.rate = 0.5"
-  nw <- network.initialize(n = 25, directed = FALSE)
+  nw <- network_initialize(n = 25)
   est <- netest(nw, formation = ~edges, target.stats = 12,
                 coef.diss = dissolution_coefs(~offset(edges), 10, 0.01),
                 edapprox = TRUE, verbose = FALSE)
   param <- param.net(inf.prob = 0.5, act.rate = 2,
-                     a.rate = 0.01, ds.rate = 0.5,
-                     di.rate = 0.25)
+                     a.rate = 0.01, ds.rate = 0.25,
+                     di.rate = 0.1)
   init <- init.net(i.num = 10)
-  control <- control.net(type = "SI", nsteps = 25,
-                         nsims = 1, tea.status = FALSE,
-                         verbose = FALSE)
+  control <- control.net(type = "SI", nsteps = 25, nsims = 1,
+                         resimulate.network = TRUE, verbose = FALSE)
   x <- netsim(est, param, init, control)
   expect_equal(unique(sapply(x$epi, nrow)), 25)
   summary(x, at = 25)
@@ -316,10 +313,10 @@ test_that("High departure rate models", {
 
   ## "netsim: 1M, di.rate = 0.5"
   param <- param.net(inf.prob = 0.1, act.rate = 2, a.rate = 0.01,
-                     ds.rate = 0.01, di.rate = 0.5)
+                     ds.rate = 0.01, di.rate = 0.25)
   init <- init.net(i.num = 10)
-  control <- control.net(type = "SI", nsteps = 25,
-                         nsims = 1, tea.status = FALSE, verbose = FALSE)
+  control <- control.net(type = "SI", nsteps = 25, nsims = 1,
+                         resimulate.network = TRUE, verbose = FALSE)
   x <- netsim(est, param, init, control)
   expect_equal(unique(sapply(x$epi, nrow)), 25)
   expect_output(summary(x, at = 25), "EpiModel Summary")
@@ -334,45 +331,47 @@ test_that("High departure rate models", {
 
 ################################################################################
 
-test_that("edges bipartite models", {
+test_that("edges two-group models", {
   skip_on_cran()
 
-  nw <- network.initialize(n = 100, bipartite = 50, directed = FALSE)
+  nw <- network_initialize(n = 100)
+  nw <- set_vertex_attribute(nw, "group", rep(1:2, each = 50))
   est5 <- netest(nw, formation = ~edges, target.stats = 25,
                  coef.diss = dissolution_coefs(~offset(edges), 10, 0),
                  edapprox = TRUE, verbose = FALSE)
   expect_is(est5, "netest")
 
   ## "SI, 2M, CL: 2 sim"
-  param <- param.net(inf.prob = 0.5, inf.prob.m2 = 0.1)
-  init <- init.net(i.num = 10, i.num.m2 = 0)
+  param <- param.net(inf.prob = 0.5, inf.prob.g2 = 0.1)
+  init <- init.net(i.num = 10, i.num.g2 = 0)
   control <- control.net(type = "SI", nsims = 2, nsteps = 25,
-                         verbose = FALSE, tea.status = FALSE)
+                         verbose = FALSE)
   x <- netsim(est5, param, init, control)
   expect_is(x, "netsim")
   expect_is(as.data.frame(x), "data.frame")
-  expect_equal(x$param$modes, 2)
+  expect_equal(x$param$groups, 2)
   expect_output(summary(x, at = 25), "EpiModel Summary")
   plot(x)
   plot(x, y = "si.flow", mean.smooth = TRUE)
   plot(x, type = "formation")
   plot(x, type = "network")
-  plot(x, type = "network", shp.bip = "triangle")
-  expect_error(plot(x, type = "network", shp.bip = TRUE))
+  plot(x, type = "network", shp.g2 = "triangle")
+  #FLAG: Adding "two-group" attribute to network type
+  expect_error(plot(x, type = "network", shp.g2 = TRUE))
   test_net(x)
   rm(x)
 
   ## "SIR, 2M, CL: 2 sim"
-  param <- param.net(inf.prob = 0.5, inf.prob.m2 = 0.1,
-                     rec.rate = 0.1, rec.rate.m2 = 0.1)
-  init <- init.net(i.num = 10, i.num.m2 = 10,
-                   r.num = 0, r.num.m2 = 0)
+  param <- param.net(inf.prob = 0.5, inf.prob.g2 = 0.1,
+                     rec.rate = 0.1, rec.rate.g2 = 0.1)
+  init <- init.net(i.num = 10, i.num.g2 = 10,
+                   r.num = 0, r.num.g2 = 0)
   control <- control.net(type = "SIR", nsims = 2, nsteps = 25,
-                         verbose = FALSE, tea.status = FALSE)
+                         verbose = FALSE)
   x <- netsim(est5, param, init, control)
   expect_is(x, "netsim")
   expect_is(as.data.frame(x), "data.frame")
-  expect_equal(x$param$modes, 2)
+  expect_equal(x$param$groups, 2)
   expect_output(summary(x, at = 25), "EpiModel Summary")
   plot(x)
   plot(x, y = "si.flow", mean.smooth = TRUE)
@@ -381,15 +380,15 @@ test_that("edges bipartite models", {
   rm(x)
 
   ## "SIR, 2M, CL: rec.rate = 0"
-  param <- param.net(inf.prob = 0.5, inf.prob.m2 = 0.25,
-                     rec.rate = 0, rec.rate.m2 = 0, act.rate = 2)
-  init <- init.net(i.num = 10, i.num.m2 = 10,
-                   r.num = 0, r.num.m2 = 0)
+  param <- param.net(inf.prob = 0.5, inf.prob.g2 = 0.25,
+                     rec.rate = 0, rec.rate.g2 = 0, act.rate = 2)
+  init <- init.net(i.num = 10, i.num.g2 = 10,
+                   r.num = 0, r.num.g2 = 0)
   control <- control.net(type = "SIR", nsteps = 10, nsims = 2,
-                         verbose = FALSE, tea.status = FALSE)
+                         verbose = FALSE)
   x <- netsim(est5, param, init, control)
-  expect_equal(max(x$epi$ir.flow), 0)
-  expect_equal(max(x$epi$ir.flow.m2), 0)
+  expect_equal(max(x$epi$ir.flow, na.rm = TRUE), 0)
+  expect_equal(max(x$epi$ir.flow.g2, na.rm = TRUE), 0)
   expect_output(summary(x, at = 10), "EpiModel Summary")
   plot(x)
   plot(x, y = "si.flow", mean.smooth = TRUE)
@@ -398,15 +397,15 @@ test_that("edges bipartite models", {
   rm(x)
 
   ## "SIS, 2M, CL: 2 sim"
-  param <- param.net(inf.prob = 0.5, inf.prob.m2 = 0.25,
-                     rec.rate = 0.01, rec.rate.m2 = 0.01)
-  init <- init.net(i.num = 10, i.num.m2 = 10)
+  param <- param.net(inf.prob = 0.5, inf.prob.g2 = 0.25,
+                     rec.rate = 0.01, rec.rate.g2 = 0.01)
+  init <- init.net(i.num = 10, i.num.g2 = 10)
   control <- control.net(type = "SIS", nsims = 2, nsteps = 25,
-                         tea.status = FALSE, verbose = FALSE)
+                         verbose = FALSE)
   x <- netsim(est5, param, init, control)
   expect_is(x, "netsim")
   expect_is(as.data.frame(x), "data.frame")
-  expect_equal(x$param$modes, 2)
+  expect_equal(x$param$groups, 2)
   expect_output(summary(x, at = 25), "EpiModel Summary")
   plot(x)
   plot(x, y = "si.flow", mean.smooth = TRUE)
@@ -415,14 +414,14 @@ test_that("edges bipartite models", {
   rm(x)
 
   ## "SIS, 2M, CL: rec.rate = 0"
-  param <- param.net(inf.prob = 0.5, inf.prob.m2 = 0.25,
-                     rec.rate = 0, rec.rate.m2 = 0, act.rate = 2)
-  init <- init.net(i.num = 10, i.num.m2 = 10)
+  param <- param.net(inf.prob = 0.5, inf.prob.g2 = 0.25,
+                     rec.rate = 0, rec.rate.g2 = 0, act.rate = 2)
+  init <- init.net(i.num = 10, i.num.g2 = 10)
   control <- control.net(type = "SIS", nsteps = 10, nsims = 2,
-                         verbose = FALSE, tea.status = FALSE)
+                         verbose = FALSE)
   x <- netsim(est5, param, init, control)
-  expect_equal(max(x$epi$is.flow), 0)
-  expect_equal(max(x$epi$is.flow.m2), 0)
+  expect_equal(max(x$epi$is.flow, na.rm = TRUE), 0)
+  expect_equal(max(x$epi$is.flow.g2, na.rm = TRUE), 0)
   expect_output(summary(x, at = 10), "EpiModel Summary")
   plot(x)
   plot(x, y = "si.flow", mean.smooth = TRUE)
@@ -434,20 +433,20 @@ test_that("edges bipartite models", {
 
 ################################################################################
 
-test_that("Open population 1 mode models", {
+test_that("Open population 1 group models", {
   skip_on_cran()
 
-  nw <- network.initialize(n = 100, directed = FALSE)
+  nw <- network_initialize(n = 100)
   est.vit <- netest(nw, formation = ~edges, target.stats = 25,
-                    coef.diss = dissolution_coefs(~offset(edges), 10, 0.02),
+                    coef.diss = dissolution_coefs(~offset(edges), 10, 0.01),
                     verbose = FALSE)
 
   ## "SI, 1M, OP: 1 sim"
-  param <- param.net(inf.prob = 0.5, act.rate = 2, a.rate = 0.02,
-                     ds.rate = 0.02, di.rate = 0.02)
+  param <- param.net(inf.prob = 0.5, act.rate = 2, a.rate = 0.01,
+                     ds.rate = 0.01, di.rate = 0.01)
   init <- init.net(i.num = 10)
   control <- control.net(type = "SI", nsteps = 10, nsims = 1,
-                         verbose = FALSE, tea.status = FALSE)
+                         resimulate.network = TRUE, verbose = FALSE)
   x <- netsim(est.vit, param, init, control)
   expect_is(x, "netsim")
   expect_is(as.data.frame(x), "data.frame")
@@ -459,29 +458,12 @@ test_that("Open population 1 mode models", {
   test_net(x)
   rm(x)
 
-  ## "SI, 1M, OP, deterministic arrivals and departures: 1 sim"
-  param <- param.net(inf.prob = 0.5, act.rate = 2, a.rate = 0.02,
-                     ds.rate = 0.02, di.rate = 0.02)
-  init <- init.net(i.num = 10)
-  control <- control.net(type = "SI", nsteps = 25, nsims = 1,
-                         verbose = FALSE, tea.status = FALSE,
-                         a.rand = FALSE, d.rand = FALSE)
-  x <- netsim(est.vit, param, init, control)
-  expect_is(x, "netsim")
-  expect_is(as.data.frame(x), "data.frame")
-  expect_equal(x$param$vital, TRUE)
-  expect_output(summary(x, at = 10), "EpiModel Summary")
-  test_net(x)
-  rm(x)
-
   ## "SI, 1M, OP: 2 sim"
-  param <- param.net(inf.prob = 0.5, act.rate = 2, a.rate = 0.02,
-                     ds.rate = 0.02, di.rate = 0.02)
+  param <- param.net(inf.prob = 0.5, act.rate = 2, a.rate = 0.01,
+                     ds.rate = 0.01, di.rate = 0.01)
   init <- init.net(i.num = 10)
-  control <- control.net(type = "SI", nsteps = 10,
-                         nsims = 2,
-                         verbose = FALSE,
-                         tea.status = FALSE)
+  control <- control.net(type = "SI", nsteps = 10, nsims = 2,
+                         resimulate.network = TRUE, verbose = FALSE)
   x <- netsim(est.vit, param, init, control)
   expect_is(x, "netsim")
   expect_is(as.data.frame(x), "data.frame")
@@ -495,11 +477,11 @@ test_that("Open population 1 mode models", {
 
   ## "SIR, 1M OP: 1 sim"
   param <- param.net(inf.prob = 0.5, rec.rate = 0.1, act.rate = 2,
-                     a.rate = 0.02, ds.rate = 0.02, di.rate = 0.02,
-                     dr.rate = 0.02)
+                     a.rate = 0.01, ds.rate = 0.01, di.rate = 0.01,
+                     dr.rate = 0.01)
   init <- init.net(i.num = 10, r.num = 0)
   control <- control.net(type = "SIR", nsteps = 10, nsims = 1,
-                         verbose = FALSE, tea.status = FALSE)
+                         resimulate.network = TRUE, verbose = FALSE)
   x <- netsim(est.vit, param, init, control)
   expect_is(x, "netsim")
   expect_is(as.data.frame(x), "data.frame")
@@ -511,29 +493,13 @@ test_that("Open population 1 mode models", {
   test_net(x)
   rm(x)
 
-  ## "SIR, 1M OP, deterministic arrivals, recoveries and departures: 1 sim"
-  param <- param.net(inf.prob = 0.5, rec.rate = 0.1, act.rate = 2,
-                     a.rate = 0.02, ds.rate = 0.02, di.rate = 0.02,
-                     dr.rate = 0.02)
-  init <- init.net(i.num = 10, r.num = 0)
-  control <- control.net(type = "SIR", nsteps = 25, nsims = 1,
-                         verbose = FALSE, tea.status = FALSE,
-                         a.rand = FALSE, d.rand = FALSE, rec.rand = FALSE)
-  x <- netsim(est.vit, param, init, control)
-  expect_is(x, "netsim")
-  expect_is(as.data.frame(x), "data.frame")
-  expect_equal(x$param$vital, TRUE)
-  expect_output(summary(x, at = 10), "EpiModel Summary")
-  test_net(x)
-  rm(x)
-
   ## "SIR, 1M, OP: 2 sim"
   param <- param.net(inf.prob = 0.5, rec.rate = 0.1, act.rate = 2,
-                     a.rate = 0.02, ds.rate = 0.02, di.rate = 0.02,
-                     dr.rate = 0.02)
+                     a.rate = 0.01, ds.rate = 0.01, di.rate = 0.01,
+                     dr.rate = 0.01)
   init <- init.net(i.num = 10, r.num = 0)
   control <- control.net(type = "SIR", nsteps = 10, nsims = 2,
-                         verbose = FALSE, tea.status = FALSE)
+                         resimulate.network = TRUE, verbose = FALSE)
   x <- netsim(est.vit, param, init, control)
   expect_is(x, "netsim")
   expect_is(as.data.frame(x), "data.frame")
@@ -547,10 +513,10 @@ test_that("Open population 1 mode models", {
 
   ## "SIS, 1M, OP: 1 sim"
   param <- param.net(inf.prob = 0.5, rec.rate = 0.01, act.rate = 2,
-                     a.rate = 0.02, ds.rate = 0.02, di.rate = 0.02)
+                     a.rate = 0.01, ds.rate = 0.01, di.rate = 0.01)
   init <- init.net(i.num = 10)
   control <- control.net(type = "SIS", nsteps = 10, nsims = 1,
-                         verbose = FALSE, tea.status = FALSE)
+                         resimulate.network = TRUE, verbose = FALSE)
   x <- netsim(est.vit, param, init, control)
   expect_is(x, "netsim")
   expect_is(as.data.frame(x), "data.frame")
@@ -564,7 +530,7 @@ test_that("Open population 1 mode models", {
 
   ## "SIS, 1M, OP: 2 sim"
   control <- control.net(type = "SIS", nsteps = 10, nsims = 2,
-                         verbose = FALSE, tea.status = FALSE)
+                         resimulate.network = TRUE, verbose = FALSE)
   x <- netsim(est.vit, param, init, control)
   expect_is(x, "netsim")
   expect_is(as.data.frame(x), "data.frame")
@@ -580,21 +546,23 @@ test_that("Open population 1 mode models", {
 
 ################################################################################
 
-test_that("Open-population bipartite models", {
+test_that("Open-population two-group models", {
   skip_on_cran()
 
-  nw <- network.initialize(n = 100, bipartite = 50, directed = FALSE)
-  est5.vit <- netest(nw, formation = ~edges, target.stats = 25,
-                     coef.diss = dissolution_coefs(~offset(edges), 10, 0.02),
+  nw <- network_initialize(n = 100, directed = FALSE)
+  nw <- set_vertex_attribute(nw, "group", rep(1:2, each = 50))
+  est5.vit <- netest(nw, formation = ~edges + nodematch("group"),
+                     target.stats = c(25, 0),
+                     coef.diss = dissolution_coefs(~offset(edges), 10, 0.01),
                      edapprox = TRUE, verbose = FALSE)
 
   ## "SI, 2M, OP: 1 sim"
-  param <- param.net(inf.prob = 0.5, inf.prob.m2 = 0.1, act.rate = 2,
-                     a.rate = 0.02, ds.rate = 0.02, di.rate = 0.02,
-                     a.rate.m2 = 0.02, ds.rate.m2 = 0.02, di.rate.m2 = 0.02)
-  init <- init.net(i.num = 10, i.num.m2 = 10)
+  param <- param.net(inf.prob = 0.5, inf.prob.g2 = 0.1, act.rate = 2,
+                     a.rate = 0.01, ds.rate = 0.01, di.rate = 0.01,
+                     a.rate.g2 = 0.01, ds.rate.g2 = 0.01, di.rate.g2 = 0.01)
+  init <- init.net(i.num = 10, i.num.g2 = 10)
   control <- control.net(type = "SI", nsteps = 10, nsims = 1,
-                         verbose = FALSE, tea.status = FALSE)
+                         resimulate.network = TRUE, verbose = FALSE)
   x <- netsim(est5.vit, param, init, control)
   expect_is(x, "netsim")
   expect_is(as.data.frame(x), "data.frame")
@@ -606,29 +574,14 @@ test_that("Open-population bipartite models", {
   test_net(x)
   rm(x)
 
-  ## "SI, 2M, OP, deterministic arrivals and departures: 1 sim"
-  param <- param.net(inf.prob = 0.5, inf.prob.m2 = 0.1, act.rate = 2,
-                     a.rate = 0.02, ds.rate = 0.02, di.rate = 0.02,
-                     a.rate.m2 = 0.02, ds.rate.m2 = 0.02, di.rate.m2 = 0.02)
-  init <- init.net(i.num = 10, i.num.m2 = 10)
-  control <- control.net(type = "SI", nsteps = 25, nsims = 1,
-                         verbose = FALSE, tea.status = FALSE,
-                         a.rand = FALSE, d.rand = FALSE)
-  x <- netsim(est5.vit, param, init, control)
-  expect_is(x, "netsim")
-  expect_is(as.data.frame(x), "data.frame")
-  expect_equal(x$param$vital, TRUE)
-  expect_output(summary(x, at = 10), "EpiModel Summary")
-  test_net(x)
-  rm(x)
 
   ## "SI, 2M, OP: 2 sim"
-  param <- param.net(inf.prob = 0.5, inf.prob.m2 = 0.1, act.rate = 2,
-                     a.rate = 0.02, ds.rate = 0.02, di.rate = 0.02,
-                     a.rate.m2 = 0.02, ds.rate.m2 = 0.02, di.rate.m2 = 0.02)
-  init <- init.net(i.num = 10, i.num.m2 = 10)
+  param <- param.net(inf.prob = 0.5, inf.prob.g2 = 0.1, act.rate = 2,
+                     a.rate = 0.01, ds.rate = 0.01, di.rate = 0.01,
+                     a.rate.g2 = 0.01, ds.rate.g2 = 0.01, di.rate.g2 = 0.01)
+  init <- init.net(i.num = 10, i.num.g2 = 10)
   control <- control.net(type = "SI", nsteps = 10, nsims = 2,
-                         verbose = FALSE, tea.status = FALSE)
+                         resimulate.network = TRUE, verbose = FALSE)
   x <- netsim(est5.vit, param, init, control)
   expect_is(x, "netsim")
   expect_is(as.data.frame(x), "data.frame")
@@ -641,15 +594,15 @@ test_that("Open-population bipartite models", {
   rm(x)
 
   ## "SIR, 2M, OP: 1 sim"
-  param <- param.net(inf.prob = 0.5, inf.prob.m2 = 0.1, rec.rate = 0.1,
-                     rec.rate.m2 = 0.1, act.rate = 2, a.rate = 0.02,
-                     a.rate.m2 = NA, ds.rate = 0.02, ds.rate.m2 = 0.02,
-                     di.rate = 0.02, di.rate.m2 = 0.02, dr.rate = 0.02,
-                     dr.rate.m2 = 0.02)
-  init <- init.net(i.num = 10, i.num.m2 = 0,
-                   r.num = 0, r.num.m2 = 10)
+  param <- param.net(inf.prob = 0.5, inf.prob.g2 = 0.1, rec.rate = 0.1,
+                     rec.rate.g2 = 0.1, act.rate = 2, a.rate = 0.01,
+                     a.rate.g2 = NA, ds.rate = 0.01, ds.rate.g2 = 0.01,
+                     di.rate = 0.01, di.rate.g2 = 0.01, dr.rate = 0.01,
+                     dr.rate.g2 = 0.01)
+  init <- init.net(i.num = 10, i.num.g2 = 0,
+                   r.num = 0, r.num.g2 = 10)
   control <- control.net(type = "SIR", nsteps = 10, nsims = 1,
-                         verbose = FALSE, tea.status = FALSE)
+                         resimulate.network = TRUE, verbose = FALSE)
   x <- netsim(est5.vit, param, init, control)
   expect_is(x, "netsim")
   expect_is(as.data.frame(x), "data.frame")
@@ -661,29 +614,9 @@ test_that("Open-population bipartite models", {
   test_net(x)
   rm(x)
 
-
-  ## "SIR, 2M, OP, deterministic arrivals, departures, and recoveries: 1 sim"
-  param <- param.net(inf.prob = 0.5, inf.prob.m2 = 0.1, rec.rate = 0.1,
-                     rec.rate.m2 = 0.1, act.rate = 2, a.rate = 0.02,
-                     a.rate.m2 = NA, ds.rate = 0.02, ds.rate.m2 = 0.02,
-                     di.rate = 0.02, di.rate.m2 = 0.02, dr.rate = 0.02,
-                     dr.rate.m2 = 0.02)
-  init <- init.net(i.num = 10, i.num.m2 = 0,
-                   r.num = 0, r.num.m2 = 10)
-  control <- control.net(type = "SIR", nsteps = 10, nsims = 1,
-                         verbose = FALSE, tea.status = FALSE,
-                         a.rand = FALSE, d.rand = FALSE, rec.rand = FALSE)
-  x <- netsim(est5.vit, param, init, control)
-  expect_is(x, "netsim")
-  expect_is(as.data.frame(x), "data.frame")
-  expect_equal(x$param$vital, TRUE)
-  expect_output(summary(x, at = 10), "EpiModel Summary")
-  test_net(x)
-  rm(x)
-
   ## "SIR, 2M, OP: 3 sim"
   control <- control.net(type = "SIR", nsteps = 10, nsims = 2,
-                         verbose = FALSE, tea.status = FALSE)
+                         resimulate.network = TRUE, verbose = FALSE)
   x <- netsim(est5.vit, param, init, control)
   expect_is(x, "netsim")
   expect_is(as.data.frame(x), "data.frame")
@@ -702,18 +635,20 @@ test_that("Open-population bipartite models", {
 test_that("Extinction open-population models", {
   skip_on_cran()
 
-  nw <- network.initialize(n = 25, bipartite = 10, directed = FALSE)
-  est <- netest(nw, formation = ~edges, target.stats = 15,
-                coef.diss = dissolution_coefs(~offset(edges), 10, 0.02),
+  nw <- network_initialize(n = 25)
+  nw <- set_vertex_attribute(nw, "group", rep(1:2, c(15,10)))
+  est <- netest(nw, formation = ~edges + nodematch("group"),
+                target.stats = c(15, 0),
+                coef.diss = dissolution_coefs(~offset(edges), 10, 0.01),
                 edapprox = TRUE, verbose = FALSE)
 
   ## "netsim: 2M, ds.rate = 0.5"
-  param <- param.net(inf.prob = 0.1, inf.prob.m2 = 0.1, act.rate = 2,
-                     a.rate = 0.02, ds.rate = 0.5, di.rate = 0.5,
-                     a.rate.m2 = 0.02, ds.rate.m2 = 0.02, di.rate.m2 = 0.02)
-  init <- init.net(i.num = 1, i.num.m2 = 0)
+  param <- param.net(inf.prob = 0.1, inf.prob.g2 = 0.1, act.rate = 2,
+                     a.rate = 0.01, ds.rate = 0.5, di.rate = 0.5,
+                     a.rate.g2 = 0.01, ds.rate.g2 = 0.01, di.rate.g2 = 0.01)
+  init <- init.net(i.num = 5, i.num.g2 = 0)
   control <- control.net(type = "SI", nsteps = 30, nsims = 1,
-                         tea.status = FALSE, verbose = FALSE)
+                         resimulate.network = TRUE, verbose = FALSE)
   x <- netsim(est, param, init, control)
   expect_output(summary(x, at = 10), "EpiModel Summary")
   plot(x)
@@ -722,13 +657,13 @@ test_that("Extinction open-population models", {
   test_net(x)
   rm(x)
 
-  ## "netsim: 2M, ds.rate.m2 = 0.5"
-  param <- param.net(inf.prob = 0.1, inf.prob.m2 = 0.1, act.rate = 2,
-                     a.rate = 0.02, ds.rate = 0.02, di.rate = 0.02,
-                     a.rate.m2 = 0.02, ds.rate.m2 = 0.5, di.rate.m2 = 0.5)
-  init <- init.net(i.num = 1, i.num.m2 = 0)
+  ## "netsim: 2M, ds.rate.g2 = 0.5"
+  param <- param.net(inf.prob = 0.1, inf.prob.g2 = 0.1, act.rate = 2,
+                     a.rate = 0.01, ds.rate = 0.01, di.rate = 0.01,
+                     a.rate.g2 = 0.01, ds.rate.g2 = 0.5, di.rate.g2 = 0.5)
+  init <- init.net(i.num = 5, i.num.g2 = 0)
   control <- control.net(type = "SI", nsteps = 30, nsims = 1,
-                         tea.status = FALSE, verbose = FALSE)
+                         resimulate.network = TRUE, verbose = FALSE)
   x <- netsim(est, param, init, control)
   expect_output(summary(x, at = 10), "EpiModel Summary")
   plot(x)
@@ -745,8 +680,8 @@ test_that("Extinction open-population models", {
 test_that("Extended post-simulation diagnosntic tests", {
   skip_on_cran()
 
-  nw <- network.initialize(100, directed = FALSE)
-  nw <- set.vertex.attribute(nw, "risk", rep(1:5, each = 20))
+  nw <- network_initialize(n = 100)
+  nw <- set_vertex_attribute(nw, "risk", rep(1:5, each = 20))
 
   est <- netest(nw,
                 formation = ~edges + nodefactor("risk"),
@@ -794,7 +729,7 @@ test_that("Extended post-simulation diagnosntic tests", {
 test_that("status.vector and infTime.vector", {
 
   n <- 100
-  nw <- network.initialize(n = n, directed = FALSE)
+  nw <- network_initialize(n = n)
   formation <- ~edges
   target.stats <- 50
   coef.diss <- dissolution_coefs(dissolution = ~offset(edges), duration = 20)
