@@ -2,7 +2,7 @@ context("Network diagnostics")
 
 test_that("Edges only models", {
   num <- 50
-  nw <- network.initialize(num, directed = FALSE)
+  nw <- network_initialize(n = num)
   formation <- ~edges
   target.stats <- 15
   coef.diss <- dissolution_coefs(dissolution = ~offset(edges), duration = 20)
@@ -61,7 +61,7 @@ test_that("Formation plot color vector length", {
   mean.degree <- ((0*0.10) + (1*0.41) + (2*0.25) + (3*0.22))
   expected.concurrent <- n*0.49
   expected.edges <- (mean.degree)*(n/2)
-  nw <- network.initialize(n, directed = FALSE)
+  nw <- network_initialize(n = n)
   formation <- ~edges + concurrent + degrange(from = 4)
   target.stats <- c(expected.edges, expected.concurrent, 0)
   coef.diss <- dissolution_coefs(dissolution = ~offset(edges), duration = 40, d.rate = 0.01)
@@ -69,18 +69,14 @@ test_that("Formation plot color vector length", {
   dx <- netdx(est, nsims = 2, nsteps = 500,
               nwstats.formula = ~edges + meandeg + degree(0:4) + concurrent)
 
-  expect_error(plot(dx, sim.col = c("green","orange")),
-               cat("sim.col must be either missing or a vector of length 1 or nstats (", dx$nstats,")"))
-  expect_error(plot(dx, mean.col = c("green","orange")),
-               cat("mean.col must be either missing or a vector of length 1 or nstats (", dx$nstats,")"))
-  expect_error(plot(dx, targ.col = c("green","orange")),
-               cat("targ.col must be either missing or a vector of length 1 or nstats (", dx$nstats,")"))
-  expect_error(plot(dx, qnts.col = c("green","orange")),
-               cat("qnts.col must be either missing or a vector of length 1 or nstats (", dx$nstats,")"))
+  expect_error(plot(dx, sim.col = c("green","orange")))
+  expect_error(plot(dx, mean.col = c("green","orange")))
+  expect_error(plot(dx, targ.col = c("green","orange")))
+  expect_error(plot(dx, qnts.col = c("green","orange")))
 })
 
 test_that("Netdx duration and dissolution plots error when skip.dissolution = TRUE", {
-  nw <- network.initialize(100, directed = FALSE)
+  nw <- network_initialize(n = 100)
   formation <- ~edges
   target.stats <- 50
   coef.diss <- dissolution_coefs(dissolution = ~offset(edges), duration = 2)
@@ -95,8 +91,8 @@ test_that("Netdx duration and dissolution plots error when skip.dissolution = TR
 
 test_that("Offset terms", {
   n <- 50
-  nw <- network.initialize(n, directed = FALSE)
-  nw <- set.vertex.attribute(nw, "loc", rep(0:1, each = n/2))
+  nw <- network_initialize(n = n)
+  nw <- set_vertex_attribute(nw, "loc", rep(0:1, each = n/2))
   dissolution <- ~offset(edges)
   duration <- 40
   coef.diss <- dissolution_coefs(dissolution, duration)
@@ -133,8 +129,8 @@ test_that("Offset terms", {
 
 test_that("Faux offset term", {
   n <- 50
-  nw <- network.initialize(n, directed = FALSE)
-  nw <- set.vertex.attribute(nw, "loc", rep(0:1, each = n/2))
+  nw <- network_initialize(n = n)
+  nw <- set_vertex_attribute(nw, "loc", rep(0:1, each = n/2))
   coef.diss <- dissolution_coefs(dissolution = ~offset(edges), duration = 40)
   formation <- ~edges + nodemix("loc", base = c(1, 3))
   target.stats <- c(15, 0)
@@ -154,12 +150,12 @@ test_that("Faux offset term", {
 
 
 test_that("More complicated faux offset term", {
-  # skip_on_cran()
-  nw <- network.initialize(1000, directed = FALSE)
-  nw <- set.vertex.attribute(nw, "sexor",
+  skip_on_cran()
+  nw <- network_initialize(n = 1000)
+  nw <- set_vertex_attribute(nw, "sexor",
                              sample(c(rep(1,20), rep(2,460),
                                       rep(3,20), rep(4,500))))
-  nw <- set.vertex.attribute(nw, "region", sample(rep(1:5,200)))
+  nw <- set_vertex_attribute(nw, "region", sample(rep(1:5,200)))
   fit <- netest(nw,
                 formation = ~edges +
                              nodemix("sexor", base = 1) +
@@ -172,7 +168,7 @@ test_that("More complicated faux offset term", {
 
 
 test_that("Static diagnostic simulations", {
-  nw <- network.initialize(100, directed = FALSE)
+  nw <- network_initialize(n = 100)
   formation <- ~edges + concurrent
   target.stats <- c(50, 20)
   coef.diss <- dissolution_coefs(dissolution = ~offset(edges), duration = 10)
@@ -200,7 +196,7 @@ test_that("Static diagnostic simulations", {
 test_that("Parallel methods", {
   skip_on_cran()
   num <- 50
-  nw <- network.initialize(num, directed = FALSE)
+  nw <- network_initialize(n = num)
   formation <- ~edges
   target.stats <- 15
   coef.diss <- dissolution_coefs(dissolution = ~offset(edges), duration = 20)
@@ -211,7 +207,7 @@ test_that("Parallel methods", {
 })
 
 test_that("error checking", {
-  nw <- network.initialize(25, directed = FALSE)
+  nw <- network_initialize(n = 25)
   est <- netest(nw, formation = ~edges, target.stats = 25,
                 coef.diss = dissolution_coefs(~offset(edges), 10, 0),
                 edapprox = TRUE, verbose = FALSE)
@@ -220,7 +216,7 @@ test_that("error checking", {
 })
 
 test_that("Cross sectional ergm dynamic error check", {
-  nw <- network.initialize(100, directed = FALSE)
+  nw <- network_initialize(n = 100)
   formation <- ~edges
   target.stats <- 50
   coef.diss <- dissolution_coefs(dissolution = ~offset(edges), duration = 1)
@@ -231,7 +227,7 @@ test_that("Cross sectional ergm dynamic error check", {
 
 test_that("Full STERGM", {
   skip_on_cran()
-  nw <- network.initialize(n = 50, directed = FALSE)
+  nw <- network_initialize(n = 50)
   est <- netest(nw, formation = ~edges, target.stats = 25,
                 coef.diss = dissolution_coefs(~offset(edges), 10, 0),
                 edapprox = FALSE, verbose = FALSE)
@@ -246,5 +242,6 @@ test_that("Full STERGM", {
   dx <- netdx(est, nsims = 2, nsteps = 10, ncores = 2, verbose = FALSE)
   expect_is(dx, "netdx")
   expect_true(dx$nsims == 2)
+  expect_is(dx$nw, "network")
 
 })
